CliApp class

Constructors

CliApp(CliLogger logger, GitVersioner? versionerProvider(GitVersionerConfig config))
CliApp.production([CliLogger logger = const CliLogger()])

Properties

hashCode → int
The hash code for this object.
no setterinherited
logger → CliLogger
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
versionerProvider → GitVersioner? Function(GitVersionerConfig config)
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
process(List<String> args) → Future<void>
showUsage() → void
showVersion() → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

intArg(ArgResults args, String name) → int
parseCliArgs(List<String> args) → GitRevisionCliArgs