GitRevisionCliArgs class

Constructors

GitRevisionCliArgs()

Properties

baseBranch ↔ String?
getter/setter pair
fullOutput ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
name ↔ String?
getter/setter pair
repoPath ↔ String?
getter/setter pair
revision ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showHelp ↔ bool
getter/setter pair
showVersion ↔ bool
getter/setter pair
stopDebounce ↔ int
getter/setter pair
yearFactor ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toConfig() → GitVersionerConfig
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override