Commit class

Constructors

Commit(String sha1, String rawDate)

Properties

date → DateTime
no setter
hashCode → int
The hash code for this object.
no setteroverride
parsedDate ↔ DateTime?
getter/setter pair
rawDate ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sha1 ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override