GitClient class

Access git via CLI to gather information about the repo

Constructors

GitClient(String workingDir)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
headBranchName → Future<String?>
branch name of HEAD or null
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
workingDir ↔ String
getter/setter pair

Methods

branchLocalOrRemote(String branchName) → Stream<String>
returns a Stream of branchNames with prepended remotes where branchName exists
localChanges(String revision) → Future<LocalChanges?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
revList(String revision, {bool firstParentOnly = false}) → Future<List<Commit>>
sha1(String revision) → Future<String?>
full Sha1 or null
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited