LocalChanges class

Constructors

LocalChanges(int filesChanged, int additions, int deletions)
const

Properties

additions → int
final
deletions → int
final
filesChanged → int
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shortStats() → String
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Properties

none ↔ LocalChanges
getter/setter pair