GitVersioner class

Constructors

GitVersioner(GitVersionerConfig config)
always returns a version which automatically caches
factory

Properties

allFirstBaseBranchCommits → Future<List<Commit>>
All first-parent commits in baseBranch
no setter
baseBranch → Future<String>
no setter
baseBranchCommits → Future<List<Commit>>
All commits in baseBranch which are also in history of GitVersionerConfig.rev
no setter
baseBranchTimeComponent → Future<int>
no setter
commits → Future<List<Commit>>
All commits in history of GitVersionerConfig.rev
no setter
config → GitVersionerConfig
final
featureBranchCommits → Future<List<Commit>>
All commits since GitVersionerConfig.rev branched off the base branch
no setter
featureBranchOrigin → Future<Commit?>
Commit where the featureBranch branched off the baseBranch or the first commit in history in case of an unrelated history
no setter
featureBranchTimeComponent → Future<int>
no setter
gitClient → GitClient
final
hashCode → int
The hash code for this object.
no setterinherited
headBranchName → Future<String?>
branch name of HEAD or null
no setter
localChanges → Future<LocalChanges?>
no setter
revision → Future<int>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sha1 → Future<String?>
full Sha1 or null
no setter
versionName → Future<String>
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

defaultStopDebounce ↔ int
getter/setter pair
defaultYearFactor ↔ int
getter/setter pair